@@ -2,6 +2,6 @@ from .brokers.memory import MemoryBroker
 from .brokers.redis import RedisBroker
 from .const import VERSION
 from .engine import Engine
-from .task import Tasks, Batch, RetryException
+from .task import Tasks, Batch, RetryException, AbortException
 
 __version__ = VERSION
